import typing as t
from dataclasses import dataclass

import click

from unstructured_ingest.cli.base.src import BaseSrcCmd
from unstructured_ingest.cli.interfaces import (
    CliConfig,
)
from unstructured_ingest.connector.reddit import SimpleRedditConfig


@dataclass
class RedditCliConfig(SimpleRedditConfig, CliConfig):
    @staticmethod
    def get_cli_options() -> t.List[click.Option]:
        options = [
            click.Option(
                ["--client-id"],
                required=True,
                type=str,
                help="The client ID, see "
                "https://praw.readthedocs.io/en/stable/getting_started/quick_start.html#prerequisites"  # noqa: E501
                " for more information.",
            ),
            click.Option(
                ["--client-secret"],
                required=True,
                type=str,
                help="The client secret, see "
                "https://praw.readthedocs.io/en/stable/getting_started/quick_start.html#prerequisites"  # noqa: E501
                " for more information.",
            ),
            click.Option(
                ["--subreddit-name"],
                required=True,
                type=str,
                help='The name of a subreddit, without the "r\\", e.g. "machinelearning"',
            ),
            click.Option(
                ["--search-query"],
                default=None,
                type=str,
                help="If set, return posts using this query. Otherwise, use hot posts.",
            ),
            click.Option(
                ["--num-posts"],
                required=True,
                type=click.IntRange(0),
                help="If set, limits the number of posts to pull in.",
            ),
            click.Option(
                ["--user-agent"],
                required=True,
                type=str,
                help="user agent request header to use when calling Reddit API",
            ),
        ]
        return options


def get_base_src_cmd() -> BaseSrcCmd:
    cmd_cls = BaseSrcCmd(
        cmd_name="reddit",
        cli_config=RedditCliConfig,
    )
    return cmd_cls



from dataclasses import dataclass, field
from pathlib import Path
from typing import Any

from unstructured_ingest.utils.data_prep import get_data, write_data
from unstructured_ingest.v2.interfaces import FileData, UploadStager, UploadStagerConfig


class BlobStoreUploadStagerConfig(UploadStagerConfig):
    pass


@dataclass
class BlobStoreUploadStager(UploadStager):
    upload_stager_config: BlobStoreUploadStagerConfig = field(
        default_factory=BlobStoreUploadStagerConfig
    )

    def run(
        self,
        elements_filepath: Path,
        file_data: FileData,
        output_dir: Path,
        output_filename: str,
        **kwargs: Any,
    ) -> Path:
        output_file = self.get_output_path(output_filename=output_filename, output_dir=output_dir)
        # Always save as json
        data = get_data(elements_filepath)
        write_data(path=output_file.with_suffix(".json"), data=data)
        return output_file.with_suffix(".json")



import json
import os
from dataclasses import dataclass
from pathlib import Path

from test.integration.embedders.utils import validate_embedding_output, validate_raw_embedder
from test.integration.utils import requires_env
from unstructured_ingest.embed.azure_openai import (
    AzureOpenAIEmbeddingConfig,
    AzureOpenAIEmbeddingEncoder,
)
from unstructured_ingest.v2.processes.embedder import Embedder, EmbedderConfig

API_KEY = "AZURE_OPENAI_API_KEY"
ENDPOINT = "AZURE_OPENAI_ENDPOINT"


@dataclass(frozen=True)
class AzureData:
    api_key: str
    endpoint: str


def get_azure_data() -> AzureData:
    api_key = os.getenv(API_KEY, None)
    assert api_key
    endpoint = os.getenv(ENDPOINT, None)
    assert endpoint
    return AzureData(api_key, endpoint)


@requires_env(API_KEY, ENDPOINT)
def test_azure_openai_embedder(embedder_file: Path):
    azure_data = get_azure_data()
    embedder_config = EmbedderConfig(
        embedding_provider="azure-openai",
        embedding_api_key=azure_data.api_key,
        embedding_azure_endpoint=azure_data.endpoint,
    )
    embedder = Embedder(config=embedder_config)
    results = embedder.run(elements_filepath=embedder_file)
    assert results
    with embedder_file.open("r") as f:
        original_elements = json.load(f)
    validate_embedding_output(original_elements=original_elements, output_elements=results)


@requires_env(API_KEY, ENDPOINT)
def test_raw_azure_openai_embedder(embedder_file: Path):
    azure_data = get_azure_data()
    embedder = AzureOpenAIEmbeddingEncoder(
        config=AzureOpenAIEmbeddingConfig(
            api_key=azure_data.api_key,
            azure_endpoint=azure_data.endpoint,
        )
    )
    validate_raw_embedder(embedder=embedder, embedder_file=embedder_file, expected_dimension=1536)



import typing as t
from dataclasses import dataclass

import click

from unstructured_ingest.cli.base.src import BaseSrcCmd
from unstructured_ingest.cli.interfaces import (
    CliConfig,
    DelimitedString,
)
from unstructured_ingest.connector.jira import SimpleJiraConfig


@dataclass
class JiraCliConfig(SimpleJiraConfig, CliConfig):
    @staticmethod
    def get_cli_options() -> t.List[click.Option]:
        options = [
            click.Option(
                ["--api-token"],
                required=True,
                type=str,
                help="API Token to authenticate into Jira (into Atlassian). \
                    Check \
                    https://developer.atlassian.com/cloud/jira/platform/basic-auth-for-rest-apis/ \
                    for more info.",
            ),
            click.Option(
                ["--url"],
                required=True,
                type=str,
                help="URL to Atlassian (Jira) Cloud, e.g. "
                '"unstructured-jira-connector-test.atlassian.net"',
            ),
            click.Option(
                ["--user-email"],
                required=True,
                type=str,
                help="Email to authenticate into Atlassian (Jira) Cloud.",
            ),
            click.Option(
                ["--projects"],
                default=None,
                type=DelimitedString(),
                help="Comma-delimited Project ids or keys. Use Jira UI or the "
                "API to find or obtain keys. Alternatively, use API to obtain ids.",
            ),
            click.Option(
                ["--boards"],
                default=None,
                type=DelimitedString(),
                help="Comma-delimited Board ids. Check board URL, or use the "
                "API to find the board ids.",
            ),
            click.Option(
                ["--issues"],
                default=None,
                type=DelimitedString(),
                help="Comma-delimited Issue ids or keys. Use Jira UI or the API to "
                "find or obtain keys. Alternatively, use API to obtain ids.",
            ),
        ]
        return options


def get_base_src_cmd() -> BaseSrcCmd:
    cmd_cls = BaseSrcCmd(
        cmd_name="jira",
        cli_config=JiraCliConfig,
    )
    return cmd_cls



import json
from pathlib import Path

from test.integration.embedders.utils import validate_embedding_output, validate_raw_embedder
from unstructured_ingest.embed.huggingface import (
    HuggingFaceEmbeddingConfig,
    HuggingFaceEmbeddingEncoder,
)
from unstructured_ingest.v2.processes.embedder import Embedder, EmbedderConfig


def test_huggingface_embedder(embedder_file: Path):
    embedder_config = EmbedderConfig(embedding_provider="huggingface")
    embedder = Embedder(config=embedder_config)
    results = embedder.run(elements_filepath=embedder_file)
    assert results
    with embedder_file.open("r") as f:
        original_elements = json.load(f)
    validate_embedding_output(original_elements=original_elements, output_elements=results)


def test_raw_hugginface_embedder(embedder_file: Path):
    embedder = HuggingFaceEmbeddingEncoder(config=HuggingFaceEmbeddingConfig())
    validate_raw_embedder(embedder=embedder, embedder_file=embedder_file, expected_dimension=384)
